#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MonadRandom
version:              0.6.2.1
visibility:           public
id:                   MonadRandom-0.6.2.1-9SAfplrUVyh9YW7PNQXwSG
key:                  MonadRandom-0.6.2.1-9SAfplrUVyh9YW7PNQXwSG
license:              BSD-3-Clause
maintainer:           Brent Yorgey <byorgey@gmail.com>
author:               Cale Gibbard and others
synopsis:             Random-number generation monad.
description:          Support for computations which consume random values.
category:             Control
abi:                  8c2cf7469a2d407486dba97f6a020563
exposed:              True
exposed-modules:
    Control.Monad.Random Control.Monad.Random.Class
    Control.Monad.Random.Lazy Control.Monad.Random.Strict
    Control.Monad.Trans.Random Control.Monad.Trans.Random.Lazy
    Control.Monad.Trans.Random.Strict

import-dirs:          /usr/lib/ghc-9.6.6/site-local/MonadRandom-0.6.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/MonadRandom-0.6.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/MonadRandom-0.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monadrandom
hs-libraries:         HSMonadRandom-0.6.2.1-9SAfplrUVyh9YW7PNQXwSG
depends:
    base-4.18.2.1 mtl-2.3.1 primitive-0.9.1.0-J4tB0B9QUoG4JNvPWMquph
    random-1.2.1.3-HWePNsfMjqy9mivdeOZEPQ transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-monadrandom/html/MonadRandom.haddock
haddock-html:         /usr/share/doc/haskell-monadrandom/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

